==> ims.j2jsoftwaresolutions.in_03_09_2024.tgz: ims.j2jsoftwaresolutions.in/includes/masters/appcommon/schemes/list.php <==
            <div class="user-dashboard">
                <div class="container">
                <div class="col-xl-12 col-lg-12">
                    <div class="row">
                        <div class="col-6"> 
                            <h3>Scheme Names</h3>
                         </div>
                         <div class="col-6" style="text-align: right;"> 
                            <button class="btn-save" onclick="addform()">New</button>
                         </div>
                        </div>                                                 
                        </div>
                   <div class="row">
                <div class="col-xl-12 col-lg-12">
                    <div class="transactions-table table">
                        <div class="table">
                            <table id="example" class="table" style="width:100%">
                                <thead>
                                    <tr>
                                        <th>Code</th>
                                        <th>Scheme Name</th>
                                        <th>Status</th>
                                        <th></th>
                                        <th></th>
                                    </tr>
                                </thead>
                                <tbody>
                                     <tr>
                                        <td></td>                                                          
                                        <td></td>           
                                        <td></td>
                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="editform()" class="btn-save">Edit</a></td>
                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="viewform()" class="btn-save">View</a></td>
                                     </tr>
                                   </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
            </div>
</div>
<div class="modal fade" id="confirmation" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">Confirmation</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                Successfully done.
            </div>
            <div class="modal-footer">
                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>

<div class="modal fade" id="confirmationtoadd" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">New Scheme Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="row">
                    <div class="col-6">
                        <label class="form-label">Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
                        <span id="ErrCode" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Scheme Name</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" name="SchemeName" id="SchemeName" placeholder="Scheme Name" onkeypress="clearInput('SchemeName')">
                        <span id="ErrSchemeName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Remarks</label>
                        <input class="form-control form-control-sm" type="text" id="Remarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('Remarks')">
                        <span id="ErrRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                </div>
            </div>
            <div class="modal-footer">
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="add()" class="btn-save">Save</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>
                                                                                                            
<div class="modal fade" id="confirmationtoedit" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">Edit Scheme Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="row">
                    <div class="col-6">
                        <label class="form-label">Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="editCode" name="Code" placeholder="Code" value="<?php echo $data[0]['Code'];?>" onkeypress="clearInput('editCode')">
                        <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                    </div>
                     <div class="col-12">
                        <label class="form-label">Scheme Name</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" name="SchemeName" id="editSchemeName" placeholder="Scheme Name" value="<?php echo $data[0]['SchemeName'];?>" onkeypress="clearInput('editSchemeName')">
                        <span id="ErreditSchemeName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Remarks</label>
                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="<?php echo $data[0]['Remarks'];?>" onkeypress="clearInput('editRemarks')">
                        <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-sm-6">
                        <label class="form-label">Status</label>
                        <select name="Status" id="editStatus" class="form-select form-select-sm">
                            <option value="1" <?php echo ($data[0]['Status']==1) ? " selected='selected' ": "''";?>>Active</option>
                            <option value="0" <?php echo ($data[0]['Status']==0) ? " selected='selected' ": "''";?>>DeActive</option>
                        </select>
                    </div>
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="edit()" class="btn-save">Update</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>

<div class="modal fade" id="confirmationtoview" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">View Scheme Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="row">
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Code</div>
                        <?php echo $data[0]['Code'];?>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Scheme Name</div>
                        <?php echo $data[0]['SchemeName'];?>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Remarks</div>
                        <?php echo $data[0]['Remarks'];?>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Status</div>
                        <?php echo $data[0]['Status'];?>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Created On</div>
                        <?php echo $data[0]['CreatedOn'];?>
                    </div>
                </div>
            </div>
            <div class="modal-footer"> 
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>
<div class="modal fade" id="Success" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-body" style="text-align: center;">
                <div id="sucess">
                    <img id="Sucess" style="width: 150px;" src="assets/sucess.gif" alt=""/>
                </div>
                <h3 class="title">Success.</h3>  
                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>         
            </div>
        </div>
    </div>
</div>
     
<script>
function view(){
      $('#confirmation').modal("show"); 
      
}

function addform(){
        $('#confirmationtoadd').modal("show"); 
        $('#Code').html(""); 
        $('#SchemeName').html(""); 
        $('#Remarks').html(""); 
        $("#Code").removeClass("highlight_error"); 
        $("#SchemeName").removeClass("highlight_error"); 
        $("#Remarks").removeClass("highlight_error"); 
}

function add(){
         var error = 0;
       if ($('#Code').val()==""){
            $('#ErrCode').html("Please enter Code");
          Code.style.border = "1px solid #dc3545";
          document.getElementById("Code").style["boxShadow"] = "0 0 5px #dc3545";
           error++;
    }  else {
         document.getElementById("Code").style["boxShadow"] = "";
            $('#ErrCode').html(""); 
    }
    if ($('#SchemeName').val()==""){
            $('#ErrSchemeName').html("Please enter Scheme Name");
         SchemeName.style.border = "1px solid #dc3545";
          document.getElementById("SchemeName").style["boxShadow"] = "0 0 5px #dc3545";
           error++;
    }  else {
         document.getElementById("SchemeName").style["boxShadow"] = "";
            $('#ErrSchemeName').html(""); 
    } 
     if (error==0){
       $('#confirmationtoadd').modal("hide"); 
       $('#Success').modal("show");  
    }
}

function editform(){
     $('#confirmationtoedit').modal("show");
     $("#editCode").removeClass("highlight_error"); 
     $("#editSchemeName").removeClass("highlight_error"); 
     $("#editRemarks").removeClass("highlight_error"); 
}

function edit(){
     var error = 0;
    if ($('#editCode').val()==""){
            $('#ErreditCode').html("Please enter Code");
         $("#editCode").addClass("highlight_error"); 
            error++;
    }  else {
        $("#editCode").removeClass("highlight_error"); 
            $('#ErreditCode').html(""); 
    }
     if ($('#editSchemeName').val()==""){
            $('#ErreditSchemeName').html("Please enter Scheme Name");
            $("#editSchemeName").addClass("highlight_error"); 
           error++;
    }  else {
            $("#editSchemeName").removeClass("highlight_error"); 
            $('#ErreditSchemeName').html(""); 
    } 
     if (error==0){
       $('#confirmationtoedit').modal("hide"); 
       $('#Success').modal("show");  
    }
}

function viewform(){
     $('#confirmationtoview').modal("show"); 
}


function dashboard()  {
  location.href='dashboard.php';                                                              
}
 
  //Character Limitations
 

/*Alphanumeric without space*/
var arr = ["Code","editCode"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
                var notallowkeys = [48,49,50,51,52,53,54,55,56,57,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46]
                var allowedkeys  = [96,97,98,99,100,101,102,103,104,105,9,8,16,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,48,49,50,51,52,53,54,55,56,57,33,34,35,36,37,38,39,40,45,12]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}


/* Alphabets Space Dot only correct */ 
var arr = ["SchemeName","editSchemeName"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
                var notallowkeys = [48,49,50,51,52,53,54,55,56,57,186,187,189,173,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46,103,104,105,100,101,102,97,98,99,96,110]
                var allowedkeys  = [9,190,8,32,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,110]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}



/* Alphnumeric and special characters, not allow !\$"'~  */
var arr = ["Remarks","editRemarks"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
               var notallowkeys = [220,222,49,52,192]
               var allowedkeys  = [9,8,46,32,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,103,104,105,100,101,102,97,98,99,96,48,49,50,51,52,53,54,55,56,57,173,61,110,190,191,221,219,111,106,109,107,59,188]
               if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}            
</script>

==> ims.j2jsoftwaresolutions.in08_09.tgz: ims.j2jsoftwaresolutions.in/includes/masters/appcommon/schemes/list.php <==
            <div class="user-dashboard">
                <div class="container">
                <div class="col-xl-12 col-lg-12">
                    <div class="row">
                        <div class="col-6"> 
                            <h3>Scheme Names</h3>
                         </div>
                         <div class="col-6" style="text-align: right;"> 
                            <button class="btn-save" onclick="addform()">New</button>
                         </div>
                        </div>                                                 
                        </div>
                   <div class="row">
                <div class="col-xl-12 col-lg-12">
                    <div class="transactions-table table">
                        <div class="table">
                            <table id="example" class="table" style="width:100%">
                                <thead>
                                    <tr>
                                        <th>Code</th>
                                        <th>Scheme Name</th>
                                        <th>Status</th>
                                        <th></th>
                                        <th></th>
                                    </tr>
                                </thead>
                                <tbody>
                                     <tr>
                                        <td></td>                                                          
                                        <td></td>           
                                        <td></td>
                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="editform()" class="btn-save">Edit</a></td>
                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="viewform()" class="btn-save">View</a></td>
                                     </tr>
                                   </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
            </div>
</div>
<div class="modal fade" id="confirmation" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">Confirmation</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                Successfully done.
            </div>
            <div class="modal-footer">
                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>

<div class="modal fade" id="confirmationtoadd" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">New Scheme Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="row">
                    <div class="col-6">
                        <label class="form-label">Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
                        <span id="ErrCode" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Scheme Name</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" name="SchemeName" id="SchemeName" placeholder="Scheme Name" onkeypress="clearInput('SchemeName')">
                        <span id="ErrSchemeName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Remarks</label>
                        <input class="form-control form-control-sm" type="text" id="Remarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('Remarks')">
                        <span id="ErrRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                </div>
            </div>
            <div class="modal-footer">
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="add()" class="btn-save">Save</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>
                                                                                                            
<div class="modal fade" id="confirmationtoedit" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">Edit Scheme Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="row">
                    <div class="col-6">
                        <label class="form-label">Code</label><span style='color:red'>*</span>
                        <input class="form-control form-control-sm" type="text" id="editCode" name="Code" placeholder="Code" value="<?php echo $data[0]['Code'];?>" onkeypress="clearInput('editCode')">
                        <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                    </div>
                     <div class="col-12">
                        <label class="form-label">Scheme Name</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" name="SchemeName" id="editSchemeName" placeholder="Scheme Name" value="<?php echo $data[0]['SchemeName'];?>" onkeypress="clearInput('editSchemeName')">
                        <span id="ErreditSchemeName" class="error_msg" style="color: red;"></span>
                    </div>
                    <div class="col-sm-6">
                        <label class="form-label">Status</label>
                        <select name="Status" id="editStatus" class="form-select form-select-sm">
                            <option value="1" <?php echo ($data[0]['Status']==1) ? " selected='selected' ": "''";?>>Active</option>
                            <option value="0" <?php echo ($data[0]['Status']==0) ? " selected='selected' ": "''";?>>Deactive</option>
                        </select>
                    </div>
                    <div class="col-12">
                        <label class="form-label">Remarks</label>
                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="<?php echo $data[0]['Remarks'];?>" onkeypress="clearInput('editRemarks')">
                        <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
                    </div>
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
                 <button type="button" href="javascript:void(0)" onclick="edit()" class="btn-save">Update</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>

<div class="modal fade" id="confirmationtoview" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLabel">View Scheme Name</h5>
                <button type="button" class="btn-close" data-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="row">
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Code</div>
                        <?php echo $data[0]['Code'];?>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Scheme Name</div>
                        <?php echo $data[0]['SchemeName'];?>
                    </div>
                    <div class="col-sm-12">
                        <div style="font-weight: bold;">Remarks</div>
                        <?php echo $data[0]['Remarks'];?>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Status</div>
                        <?php echo $data[0]['Status'];?>
                    </div>
                    <div class="col-sm-6">
                        <div style="font-weight: bold;">Created On</div>
                        <?php echo $data[0]['CreatedOn'];?>
                    </div>
                </div>
            </div>
            <div class="modal-footer"> 
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
            </div>
        </div>                                                                                                                     
    </div>
</div>

<div class="modal fade" id="Success" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-body" style="text-align: center;">
                <div id="sucess">
                    <img id="Sucess" style="width: 150px;" src="assets/sucess.gif" alt=""/>
                </div>
                <h3 class="title">Success.</h3>  
                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>         
            </div>
        </div>
    </div>
</div>
     
<script>
function view(){
      $('#confirmation').modal("show"); 
      
}

function addform(){
        $('#confirmationtoadd').modal("show"); 
        $('#Code').val(""); 
        $('#SchemeName').val(""); 
        $('#Remarks').val("");
        $('#ErrCode').html("");
        $('#ErrSchemeName').html(""); 
        $('#ErrRemarks').html(""); 
        $("#Code").removeClass("highlight_error"); 
        $("#SchemeName").removeClass("highlight_error"); 
        $("#Remarks").removeClass("highlight_error"); 
}

function add(){
         var error = 0;
       if ($('#Code').val()==""){
            $('#ErrCode').html("Please enter Code");
         $("#Code").addClass("highlight_error"); 
           error++;
    }  else {
        $("#Code").removeClass("highlight_error"); 
            $('#ErrCode').html(""); 
    }
    if ($('#SchemeName').val()==""){
            $('#ErrSchemeName').html("Please enter Scheme Name");
        $("#SchemeName").addClass("highlight_error"); 
           error++;
    }  else {
         $("#SchemeName").removeClass("highlight_error"); 
            $('#ErrSchemeName').html(""); 
    } 
     if (error==0){
       $('#confirmationtoadd').modal("hide"); 
       $('#Success').modal("show");  
    }
}

function editform(){
     $('#confirmationtoedit').modal("show");
     $('#ErreditCode').html("");
     $('#ErreditSchemeName').html(""); 
     $('#ErreditRemarks').html("");
     $("#editCode").removeClass("highlight_error"); 
     $("#editSchemeName").removeClass("highlight_error"); 
     $("#editRemarks").removeClass("highlight_error"); 
}

function edit(){
     var error = 0;
    if ($('#editCode').val()==""){
            $('#ErreditCode').html("Please enter Code");
         $("#editCode").addClass("highlight_error"); 
            error++;
    }  else {
        $("#editCode").removeClass("highlight_error"); 
            $('#ErreditCode').html(""); 
    }
     if ($('#editSchemeName').val()==""){
            $('#ErreditSchemeName').html("Please enter Scheme Name");
            $("#editSchemeName").addClass("highlight_error"); 
           error++;
    }  else {
            $("#editSchemeName").removeClass("highlight_error"); 
            $('#ErreditSchemeName').html(""); 
    } 
     if (error==0){
       $('#confirmationtoedit').modal("hide"); 
       $('#Success').modal("show");  
    }
}

function viewform(){
     $('#confirmationtoview').modal("show"); 
}


function dashboard()  {
  location.href='dashboard.php';                                                              
}
 
  //Character Limitations
 

/*Alphanumeric without space*/
var arr = ["Code","editCode"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
                var notallowkeys = [48,49,50,51,52,53,54,55,56,57,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46]
                var allowedkeys  = [96,97,98,99,100,101,102,103,104,105,9,8,16,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,48,49,50,51,52,53,54,55,56,57,33,34,35,36,37,38,39,40,45,12]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}


/* Alphabets Space Dot only correct */ 
var arr = ["SchemeName","editSchemeName"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
                var notallowkeys = [48,49,50,51,52,53,54,55,56,57,186,187,189,173,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46,103,104,105,100,101,102,97,98,99,96,110]
                var allowedkeys  = [9,190,8,32,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,110]
                if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}



/* Alphnumeric and special characters, not allow !\$"'~  */
var arr = ["Remarks","editRemarks"];
for (var i=0; i<arr.length; i++) {
    if ($('#'+arr[i]).length){
        document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
            var keyCode = e.keyCode || e.which;
            if (e.ctrlKey || e.altKey) {
                e.preventDefault();
            } else {
               var notallowkeys = [220,222,49,52,192]
               var allowedkeys  = [9,8,46,32,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,103,104,105,100,101,102,97,98,99,96,48,49,50,51,52,53,54,55,56,57,173,61,110,190,191,221,219,111,106,109,107,59,188]
               if (e.shiftKey) {
                    if (notallowkeys.includes(keyCode)) {
                        e.preventDefault();
                    }
                } else {
                    if (!(allowedkeys.includes(keyCode))) {
                        e.preventDefault();
                    }
                }
            }
        });
        $('#'+arr[i]).on("cut copy paste",function(e){
            e.preventDefault();
        });  
    } 
}            
</script>
